import { Plugin } from 'vite';

type AuthRoute = {
  /** 路由名称 */
  name: string;
  path: string;
  icon?: string;
  element?: string;
  children?: AuthRoute[];
  /** 路由是否在菜单栏里隐藏 */
  hideInMenu?: boolean;
  redirect?: string;

  authKey?: string; // 手动配置的 key
  disableAuth?: boolean; // 禁当前页及其后代权限生成
};

type ExtractAuthOptions = {
  /**
   * 应用key
   */
  appKey: string;
  /**
   * 路由资源数据
   * @default []
   */
  routes: AuthRoute[];
  /**
   * 过滤未配置权限页面
   * @default ['exception', 'error', '404', '403', '500', 'DS_Store']
   */
  routeFilterRules?: string[];
  /**
   * 接口权限前缀
   * @default ''
   */
  apiPrefix?: string;
};

declare function extractAuth(options: ExtractAuthOptions): Plugin;

export { extractAuth as default };
